==> hadoop-apache2-0.3-sources.jar: com/facebook/presto/hadoop/$internal/io/netty/handler/codec/sctp/SctpMessageToMessageDecoder.java <==
/*
 * Copyright 2012 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package com.facebook.presto.hadoop.$internal.io.netty.handler.codec.sctp;

import com.facebook.presto.hadoop.$internal.io.netty.channel.sctp.SctpMessage;
import com.facebook.presto.hadoop.$internal.io.netty.handler.codec.CodecException;
import com.facebook.presto.hadoop.$internal.io.netty.handler.codec.MessageToMessageDecoder;

public abstract class SctpMessageToMessageDecoder extends MessageToMessageDecoder<SctpMessage> {

    @Override
    public boolean acceptInboundMessage(Object msg) throws Exception {
        if (msg instanceof SctpMessage) {
            SctpMessage sctpMsg = (SctpMessage) msg;
            if (sctpMsg.isComplete()) {
                return true;
            }

            throw new CodecException(String.format("Received SctpMessage is not complete, please add %s in " +
                    "the pipeline before this handler", SctpMessageCompletionHandler.class.getSimpleName()));
        } else {
            return false;
        }
    }
}

==> hadoop-apache-3.4.1-1-sources.jar: com/facebook/presto/hadoop/$internal/io/netty/handler/codec/sctp/SctpMessageToMessageDecoder.java <==
/*
 * Copyright 2012 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at:
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

package com.facebook.presto.hadoop.\$internal.io.netty.handler.codec.sctp;

import com.facebook.presto.hadoop.\$internal.io.netty.channel.sctp.SctpMessage;
import com.facebook.presto.hadoop.\$internal.io.netty.handler.codec.CodecException;
import com.facebook.presto.hadoop.\$internal.io.netty.handler.codec.MessageToMessageDecoder;

public abstract class SctpMessageToMessageDecoder extends MessageToMessageDecoder<SctpMessage> {

    @Override
    public boolean acceptInboundMessage(Object msg) throws Exception {
        if (msg instanceof SctpMessage) {
            SctpMessage sctpMsg = (SctpMessage) msg;
            if (sctpMsg.isComplete()) {
                return true;
            }

            throw new CodecException(String.format("Received SctpMessage is not complete, please add %s in " +
                    "the pipeline before this handler", SctpMessageCompletionHandler.class.getSimpleName()));
        } else {
            return false;
        }
    }
}
